<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 *
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option(JOURNALBOX_OPTIONS_PREFIXED.'optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option(JOURNALBOX_OPTIONS_PREFIXED.'optionsframework', $optionsframework_settings);

	// echo $themename;
}


/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 */
function optionsframework_options() {

	// Background Defaults
	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' ));
		
	$background_defaults = array(
		'color' => '#1B855F',
		'image' => '',
		'repeat' => 'repeat',
		'position' => '',
		'attachment'=>'scroll' );


	// Typography Defaults
	$typography_defaults = array(
		'size' => '13px',
		'face' => 'Lucida Sans Unicode',
		'style' => 'normal',
		'color' => '#1B855F' );
      
	  //Tagline Typography Defaults
	$tagline_typography_defaults = array(
		'size' => '18px',
		'face' => 'Lucida Sans Unicode',
		'style' => 'bold',
		'color' => '#ffffff' );
		
	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}

	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  JOURNALBOX_THEME_BASE_URL . '/images/';

	$options = array();
/// General Options
	$options[] = array(
		'name' => __('General Options', 'journalbox'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Upload Logo', 'journalbox'),
		'desc' => __('Upload a logo image, or enter the URL to an image if its already uploaded. The themes default logo gets applied if the input field is left blank .  Logo Dimension: 240px * 75px (if your logo is larger you might need to modify style.css to align it perfectly).', 'journalbox'),
		'id' => 'logo',
		'std' =>$imagepath .'logo.png',
		'type' => 'upload');
		
		$options[] = array( 'name' => __('Tagline Typography', 'journalbox'),
		'desc' => __('Tagline typography (Site description below logo image).', 'journalbox'),
		'id' => "tagline_typography",
		'std' => $tagline_typography_defaults,
		'type' => 'typography' );
		

    $options[] = array(
		'name' => __('Favicon', 'journalbox'),
		'desc' => __('An icon associated with a URL that is variously displayed, as in a browser\'s address bar or next to the site name in a bookmark list. Learn more about <a href="'.esc_url("http://en.wikipedia.org/wiki/Favicon").' target="_blank">Favicon</a>', 'journalbox'),
		'id' => 'favicon',
		'type' => 'upload');
		    
	$options[] = array( 'name' => __('Links Color', 'journalbox'),
		'desc' => __('All links Color.', 'journalbox'),
		'id' => "links_color",
		'std' =>'#3399CC',
		'type' => 'color' );
		
	 $options[] = array(
		'name' =>  __('Global style', 'journalbox'),
		'desc' => __('Menu, content font color and body background.', 'journalbox'),
		'id' => 'body_background',
		'std' => $background_defaults,
		'type' => 'background' );
		
	/// Footer Options
	$options[] = array(
		'name' => __('Footer Options', 'journalbox'),
		'type' => 'heading');
		
		$options[] = array( 'name' => __('Footer Font Color', 'journalbox'),
		'id' => "footer_font_color",
		'std' =>'#ffffff',
		'type' => 'color' );
		
		$options[] = array(
		'name' => __('Enable Footer Area', 'journalbox'),
		'desc' => __('Active Footer Area("About me" and "Contact Info")', 'journalbox'),
		'id' => 'enable_footer_area',
		'std' => '1',
		'type' => 'checkbox');
		
		$options[] = array(
		'name' => __('About me', 'journalbox'),
		'type' => 'group_start');
		
		$options[] = array(
		'name' => __('About Me Title', 'journalbox'),
		'id' => 'about_me_title',
		'std' => 'About Me',
		'type' => 'text');
		$options[] = array(
		'name' => __('About Me Image', 'journalbox'),
		'id' => 'about_me_image',
		'std' =>$imagepath .'about-me.png',
		'type' => 'upload');
		
		$options[] = array(
		'name' => __('About Me Description', 'journalbox'),
		'id' => 'about_me_description',
		'std' => 'Lorem ipsum dolor sit amet, consec tetuer adipiscing elit. Pra esent vestibulum molestie lacus. Aenean nonummy hendrerit mauris. Phasellus porta. Fusce suscipit varius mi. Cum sociis natoque penatibus.',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
		$options[] = array(
		'name' => __('About me', 'journalbox'),
		'type' => 'group_end');
        
		$options[] = array(
		'name' => __('Contact Info', 'journalbox'),
		'type' => 'group_start');
		$options[] = array(
		'name' => __('Contact Info Title', 'journalbox'),
		'id' => 'contact_info_title',
		'std' => 'Contact Us',
		'type' => 'text');
		$options[] = array(
		'name' => __('Contact Information', 'journalbox'),
		'id' => 'contact_info',
		'std' => '<ul><li>Address : UK, London</li><li>Call : +012-345-6789</li><li>Fax : (000) 765-4321</li><li>Email : youraddress@example.com</li>',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
         $options[] = array(
		'name' => __('Contact Info', 'journalbox'),
		'type' => 'group_end'); 
	return $options;
}